@@ -52,10 +52,10 @@ Ming_loadFont(const char* path, const char* name)
 
 
 void
-Ming_cleanupFonts()
+Ming_cleanupFonts(void)
 {
   int i;
-  
+
   if(Ming_numFonts == 0) return;
 
   for ( i = 0; i < Ming_numFonts; ++i )
@@ -66,7 +66,7 @@ Ming_cleanupFonts()
 
   if ( Ming_fontList != NULL )
     free(Ming_fontList);
-  
+
   /* yixuan--If this function is called more than once, we must reset
      Ming_numFonts */
   Ming_numFonts = 0;
